# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.samplemetadatasample import Samplemetadatasample

class TestSamplemetadatasample(unittest.TestCase):
    """Samplemetadatasample unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Samplemetadatasample:
        """Test Samplemetadatasample
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Samplemetadatasample`
        """
        model = Samplemetadatasample()
        if include_optional:
            return Samplemetadatasample(
                id = '',
                name = '',
                description = '',
                created_by = '',
                investigation_ids = '',
                icat_sample_id = '',
                icat_sample_a_form_id = '',
                metadata = [
                    icat_plus_client.models.samplemetadata.samplemetadata(
                        _id = '', 
                        name = '', 
                        value = [
                            ''
                            ], )
                    ],
                related_items = [
                    icat_plus_client.models.relateditem.relateditem(
                        _id = '', 
                        related_sample = icat_plus_client.models.samplemetadatasimplifiedsample.samplemetadatasimplifiedsample(
                            _id = '', 
                            name = '', ), 
                        relation_type = '', )
                    ]
            )
        else:
            return Samplemetadatasample(
                name = '',
        )
        """

    def testSamplemetadatasample(self):
        """Test Samplemetadatasample"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
