# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.doi_api import DOIApi


class TestDOIApi(unittest.TestCase):
    """DOIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DOIApi()

    def tearDown(self) -> None:
        pass

    def test_doi_prefix_suffix_datasets_get(self) -> None:
        """Test case for doi_prefix_suffix_datasets_get

        Returns a set of datasets given a DOI.
        """
        pass

    def test_doi_prefix_suffix_json_datacite_get(self) -> None:
        """Test case for doi_prefix_suffix_json_datacite_get

        Returns a document in a json-datacite format with the description of the DOI
        """
        pass

    def test_doi_prefix_suffix_reports_get(self) -> None:
        """Test case for doi_prefix_suffix_reports_get

        Returns the list of the experimental reports coming from the user portal and information needed for the display
        """
        pass

    def test_doi_session_id_mint_post(self) -> None:
        """Test case for doi_session_id_mint_post

        It mints a DOI
        """
        pass

    def test_doi_session_id_reserve_post(self) -> None:
        """Test case for doi_session_id_reserve_post

        It reserves a DOI
        """
        pass

    def test_doi_session_id_reserved_dois_get(self) -> None:
        """Test case for doi_session_id_reserved_dois_get

        Returns the list of reserved DOIs for a given user
        """
        pass


if __name__ == '__main__':
    unittest.main()
