# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.data_acquisition_api import DataAcquisitionApi


class TestDataAcquisitionApi(unittest.TestCase):
    """DataAcquisitionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataAcquisitionApi()

    def tearDown(self) -> None:
        pass

    def test_dataacquisition_api_key_base64_post(self) -> None:
        """Test case for dataacquisition_api_key_base64_post

        Uploads an image in base64 format to the investigation electronic logbook
        """
        pass

    def test_dataacquisition_api_key_dataset_get(self) -> None:
        """Test case for dataacquisition_api_key_dataset_get

        Gets datasets
        """
        pass

    def test_dataacquisition_api_key_dataset_restore_post(self) -> None:
        """Test case for dataacquisition_api_key_dataset_restore_post

        Update the restore status of a dataset access and send an email to the users who asked for the restoration
        """
        pass

    def test_dataacquisition_api_key_events_move_post(self) -> None:
        """Test case for dataacquisition_api_key_events_move_post

        move the events from one investigation to another
        """
        pass

    def test_dataacquisition_api_key_investigation_get(self) -> None:
        """Test case for dataacquisition_api_key_investigation_get

        Get investigations
        """
        pass

    def test_dataacquisition_api_key_mint_post(self) -> None:
        """Test case for dataacquisition_api_key_mint_post

        It mints a DOI
        """
        pass

    def test_dataacquisition_api_key_notification_post(self) -> None:
        """Test case for dataacquisition_api_key_notification_post

        Adds an event to the logbook (for an investigation or beamline logbook). It could also be a machine event
        """
        pass


if __name__ == '__main__':
    unittest.main()
