# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.sampleinformation import Sampleinformation

class TestSampleinformation(unittest.TestCase):
    """Sampleinformation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Sampleinformation:
        """Test Sampleinformation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Sampleinformation`
        """
        model = Sampleinformation()
        if include_optional:
            return Sampleinformation(
                id = '',
                investigation_id = 56,
                sample_id = 56,
                resources = [
                    icat_plus_client.models.resourceinformation.resourceinformation(
                        _id = '', 
                        filename = '', 
                        file_type = '', 
                        group_name = '', 
                        multiplicity = 1.337, 
                        file = '', )
                    ]
            )
        else:
            return Sampleinformation(
                id = '',
                investigation_id = 56,
                sample_id = 56,
        )
        """

    def testSampleinformation(self):
        """Test Sampleinformation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
