# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.ids_api import IDSApi


class TestIDSApi(unittest.TestCase):
    """IDSApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IDSApi()

    def tearDown(self) -> None:
        pass

    def test_ids_session_id_data_download_get(self) -> None:
        """Test case for ids_session_id_data_download_get

        Redirects to IDS server to download datasets or datafiles
        """
        pass

    def test_ids_session_id_datasets_restore_post(self) -> None:
        """Test case for ids_session_id_datasets_restore_post

        Records dataset restoration request by a user and redirects to IDS server to download datasets or datafiles
        """
        pass

    def test_ids_session_id_datasets_status_get(self) -> None:
        """Test case for ids_session_id_datasets_status_get

        Return the IDS status of the datasets specified by the datasetIds along with a sessionId.
        """
        pass

    def test_ids_session_id_path_get(self) -> None:
        """Test case for ids_session_id_path_get

        Returns the location of the files or datasets
        """
        pass


if __name__ == '__main__':
    unittest.main()
