# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.investigation_investigation_users_inner import InvestigationInvestigationUsersInner

class TestInvestigationInvestigationUsersInner(unittest.TestCase):
    """InvestigationInvestigationUsersInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvestigationInvestigationUsersInner:
        """Test InvestigationInvestigationUsersInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvestigationInvestigationUsersInner`
        """
        model = InvestigationInvestigationUsersInner()
        if include_optional:
            return InvestigationInvestigationUsersInner(
                role = '',
                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                    email = '', 
                    full_name = '', 
                    family_name = '', 
                    name = '', 
                    given_name = '', )
            )
        else:
            return InvestigationInvestigationUsersInner(
                role = '',
                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                    email = '', 
                    full_name = '', 
                    family_name = '', 
                    name = '', 
                    given_name = '', ),
        )
        """

    def testInvestigationInvestigationUsersInner(self):
        """Test InvestigationInvestigationUsersInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
