# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.json_datacite_dates_inner import JsonDataciteDatesInner

class TestJsonDataciteDatesInner(unittest.TestCase):
    """JsonDataciteDatesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonDataciteDatesInner:
        """Test JsonDataciteDatesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonDataciteDatesInner`
        """
        model = JsonDataciteDatesInner()
        if include_optional:
            return JsonDataciteDatesInner(
                var_date = '',
                date_type = ''
            )
        else:
            return JsonDataciteDatesInner(
        )
        """

    def testJsonDataciteDatesInner(self):
        """Test JsonDataciteDatesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
