# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.json_datacite import JsonDatacite

class TestJsonDatacite(unittest.TestCase):
    """JsonDatacite unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonDatacite:
        """Test JsonDatacite
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonDatacite`
        """
        model = JsonDatacite()
        if include_optional:
            return JsonDatacite(
                doi = '',
                url = '',
                publication_year = '',
                creators = [
                    icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                        name = '', )
                    ],
                titles = icat_plus_client.models.json_datacite_titles.json_datacite_titles(
                    title = '', ),
                publisher = '',
                subjects = [
                    icat_plus_client.models.json_datacite_subjects_inner.json_datacite_subjects_inner(
                        subject_scheme = '', )
                    ],
                dates = [
                    icat_plus_client.models.json_datacite_dates_inner.json_datacite_dates_inner(
                        date = '', 
                        date_type = '', )
                    ]
            )
        else:
            return JsonDatacite(
                doi = '',
                url = '',
                publication_year = '',
                creators = [
                    icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                        name = '', )
                    ],
                titles = icat_plus_client.models.json_datacite_titles.json_datacite_titles(
                    title = '', ),
                publisher = '',
                subjects = [
                    icat_plus_client.models.json_datacite_subjects_inner.json_datacite_subjects_inner(
                        subject_scheme = '', )
                    ],
                dates = [
                    icat_plus_client.models.json_datacite_dates_inner.json_datacite_dates_inner(
                        date = '', 
                        date_type = '', )
                    ],
        )
        """

    def testJsonDatacite(self):
        """Test JsonDatacite"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
