# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.session_api import SessionApi


class TestSessionApi(unittest.TestCase):
    """SessionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SessionApi()

    def tearDown(self) -> None:
        pass

    def test_session_post(self) -> None:
        """Test case for session_post

        This is used to log into the app
        """
        pass

    def test_session_session_id_delete(self) -> None:
        """Test case for session_session_id_delete

        Log out
        """
        pass

    def test_session_session_id_get(self) -> None:
        """Test case for session_session_id_get

        Gets information about the session in ICAT
        """
        pass

    def test_session_session_id_put(self) -> None:
        """Test case for session_session_id_put

        This is used to refresh the current session. It returns code 204 if refreshed
        """
        pass


if __name__ == '__main__':
    unittest.main()
