# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.event import Event

class TestEvent(unittest.TestCase):
    """Event unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Event:
        """Test Event
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Event`
        """
        model = Event()
        if include_optional:
            return Event(
                id = 56,
                investigation_id = 56,
                investigation_name = '',
                instrument_name = '',
                dataset_id = 56,
                type = 'notification',
                tag = [
                    icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                        name = '', )
                    ],
                title = '',
                category = 'commandline',
                filepath = '',
                filename = '',
                file_size = '',
                username = '',
                content = [
                    icat_plus_client.models.event_content_inner.event_content_inner(
                        format = '', 
                        text = '', )
                    ],
                software = '',
                machine = '',
                source = '',
                creation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                content_type = '',
                file = '',
                previous_version_event = None
            )
        else:
            return Event(
                investigation_id = 56,
                type = 'notification',
                category = 'commandline',
        )
        """

    def testEvent(self):
        """Test Event"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
