# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.ewoks_api import EWOKSApi


class TestEWOKSApi(unittest.TestCase):
    """EWOKSApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EWOKSApi()

    def tearDown(self) -> None:
        pass

    def test_ewoks_session_id_jobs_get(self) -> None:
        """Test case for ewoks_session_id_jobs_get

        Returns a list of the jobs
        """
        pass

    def test_ewoks_session_id_jobs_post(self) -> None:
        """Test case for ewoks_session_id_jobs_post

        Launch a job
        """
        pass

    def test_ewoks_session_id_jobs_put(self) -> None:
        """Test case for ewoks_session_id_jobs_put

        updates a job
        """
        pass

    def test_ewoks_session_id_workflows_get(self) -> None:
        """Test case for ewoks_session_id_workflows_get

        Returns a list with the content of the graph of each workflow
        """
        pass


if __name__ == '__main__':
    unittest.main()
