# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.investigation import Investigation

class TestInvestigation(unittest.TestCase):
    """Investigation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Investigation:
        """Test Investigation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Investigation`
        """
        model = Investigation()
        if include_optional:
            return Investigation(
                id = 1.337,
                name = '',
                start_date = '',
                end_date = '',
                doi = '',
                title = '',
                visit_id = '',
                release_date = '',
                summary = '',
                parameters = icat_plus_client.models.parameters.parameters(),
                instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                    id = 1.337, 
                    name = '', 
                    instrument_scientists = [
                        icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                            name = '', )
                        ], ),
                investigation_users = [
                    icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                        role = '', 
                        user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                            email = '', 
                            full_name = '', 
                            family_name = '', 
                            name = '', 
                            given_name = '', ), )
                    ],
                meta = icat_plus_client.models.meta.meta(
                    page = icat_plus_client.models.meta_page.meta_page(
                        total = 1.337, 
                        total_pages = 1.337, 
                        current_page = 1.337, ), ),
                type = icat_plus_client.models.investigation_type.investigation_type(
                    id = 1.337, 
                    create_id = '', 
                    create_time = '', 
                    mod_id = '', 
                    mod_time = '', 
                    description = '', 
                    name = '', ),
                can_access_datasets = True
            )
        else:
            return Investigation(
                id = 1.337,
                name = '',
                start_date = '',
        )
        """

    def testInvestigation(self):
        """Test Investigation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
