# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.elastic_search_api import ElasticSearchApi


class TestElasticSearchApi(unittest.TestCase):
    """ElasticSearchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ElasticSearchApi()

    def tearDown(self) -> None:
        pass

    def test_elasticsearch_session_id_datasets_msearch_get(self) -> None:
        """Test case for elasticsearch_session_id_datasets_msearch_get

        Proxy to elastic search server
        """
        pass

    def test_elasticsearch_session_id_stats_histogram_get(self) -> None:
        """Test case for elasticsearch_session_id_stats_histogram_get

        Gets time series statistics. Only administrator and instrumentScientists are allowed
        """
        pass

    def test_elasticsearch_session_id_stats_instrument_metrics_get(self) -> None:
        """Test case for elasticsearch_session_id_stats_instrument_metrics_get

        Given an array of dates it returns the statistics for each instrument
        """
        pass


if __name__ == '__main__':
    unittest.main()
