# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.sample import Sample

class TestSample(unittest.TestCase):
    """Sample unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Sample:
        """Test Sample
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Sample`
        """
        model = Sample()
        if include_optional:
            return Sample(
                id = 1.337,
                name = '',
                mod_time = '',
                investigation = icat_plus_client.models.sample_investigation.sample_investigation(
                    id = 1.337, 
                    name = '', 
                    start_date = '', 
                    end_date = '', 
                    title = '', 
                    visit_id = '', 
                    instrument = icat_plus_client.models.sample_investigation_instrument.sample_investigation_instrument(
                        id = 1.337, 
                        name = '', ), ),
                datasets = [
                    icat_plus_client.models.sample_datasets_inner.sample_datasets_inner(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        location = '', 
                        type = '', 
                        parameters = [
                            icat_plus_client.models.sample_datasets_inner_parameters_inner.sample_datasets_inner_parameters_inner(
                                id = 1.337, 
                                name = '', 
                                value = '', 
                                units = '', )
                            ], )
                    ],
                parameters = [
                    icat_plus_client.models.sample_datasets_inner_parameters_inner.sample_datasets_inner_parameters_inner(
                        id = 1.337, 
                        name = '', 
                        value = '', 
                        units = '', )
                    ],
                meta = icat_plus_client.models.meta.meta(
                    page = icat_plus_client.models.meta_page.meta_page(
                        total = 1.337, 
                        total_pages = 1.337, 
                        current_page = 1.337, ), )
            )
        else:
            return Sample(
                id = 1.337,
                name = '',
        )
        """

    def testSample(self):
        """Test Sample"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
