# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.tracking import Tracking

class TestTracking(unittest.TestCase):
    """Tracking unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Tracking:
        """Test Tracking
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Tracking`
        """
        model = Tracking()
        if include_optional:
            return Tracking(
                id = '',
                tracking_id = '',
                address = icat_plus_client.models.address.address(
                    _id = '', 
                    name = '', 
                    surname = '', 
                    company_name = '', 
                    address = '', 
                    city = '', 
                    region = '', 
                    postal_code = '', 
                    country = '', 
                    email = '', 
                    phone_number = '', 
                    default_courier_account = '', 
                    default_courier_company = '', )
            )
        else:
            return Tracking(
        )
        """

    def testTracking(self):
        """Test Tracking"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
