# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.datacollection import Datacollection

class TestDatacollection(unittest.TestCase):
    """Datacollection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Datacollection:
        """Test Datacollection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Datacollection`
        """
        model = Datacollection()
        if include_optional:
            return Datacollection(
                id = 1.337,
                create_id = '',
                create_time = '',
                mod_id = '',
                mod_time = '',
                data_collection_datasets = [
                    icat_plus_client.models.datacollection_data_collection_datasets_inner.datacollection_dataCollectionDatasets_inner(
                        dataset = icat_plus_client.models.datacollection_data_collection_datasets_inner_dataset.datacollection_dataCollectionDatasets_inner_dataset(
                            id = 1.337, 
                            name = '', 
                            start_date = '', 
                            end_date = '', 
                            location = '', 
                            sample_name = '', ), )
                    ]
            )
        else:
            return Datacollection(
                id = 1.337,
        )
        """

    def testDatacollection(self):
        """Test Datacollection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
