# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.job import Job

class TestJob(unittest.TestCase):
    """Job unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Job:
        """Test Job
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Job`
        """
        model = Job()
        if include_optional:
            return Job(
                id = '',
                dataset_ids = [
                    ''
                    ],
                sample_ids = [
                    ''
                    ],
                user_names = [
                    ''
                    ],
                investigations = [
                    icat_plus_client.models.job_investigations_inner.job_investigations_inner(
                        _id = '', 
                        name = '', 
                        id = '', )
                    ],
                identifier = '',
                input = None,
                logs = [
                    None
                    ],
                status = '',
                statuses = [
                    ''
                    ],
                steps = [
                    icat_plus_client.models._ewoks__session_id__jobs_put_request_step._ewoks__sessionId__jobs_put_request_step(
                        name = '', 
                        status = '', 
                        message = '', )
                    ],
                job_id = '',
                workflow = None,
                created_at = '',
                updated_at = ''
            )
        else:
            return Job(
        )
        """

    def testJob(self):
        """Test Job"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
