# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.cache_api import CacheApi


class TestCacheApi(unittest.TestCase):
    """CacheApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CacheApi()

    def tearDown(self) -> None:
        pass

    def test_cache_get(self) -> None:
        """Test case for cache_get

        Gets the cache of a user given a specific sessionId
        """
        pass

    def test_cache_keys_get(self) -> None:
        """Test case for cache_keys_get

        Gets the keys stored in the cache
        """
        pass

    def test_cache_keys_key_get(self) -> None:
        """Test case for cache_keys_key_get

        Gets the content of a key
        """
        pass

    def test_cache_session_id_post(self) -> None:
        """Test case for cache_session_id_post

        Reloads the cache
        """
        pass

    def test_cache_stats_get(self) -> None:
        """Test case for cache_stats_get

        Gets the statistics for the use of cache
        """
        pass


if __name__ == '__main__':
    unittest.main()
