# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.instrumentscientist import Instrumentscientist

class TestInstrumentscientist(unittest.TestCase):
    """Instrumentscientist unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Instrumentscientist:
        """Test Instrumentscientist
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Instrumentscientist`
        """
        model = Instrumentscientist()
        if include_optional:
            return Instrumentscientist(
                user = icat_plus_client.models.instrumentscientist_user.instrumentscientist_user(
                    name = '', 
                    full_name = '', ),
                id = '',
                mod_id = '',
                create_id = '',
                mod = icat_plus_client.models.instrumentscientist_mod.instrumentscientist_mod(
                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    user = icat_plus_client.models.instrumentscientist_user.instrumentscientist_user(
                        name = '', 
                        full_name = '', ), ),
                instrument = icat_plus_client.models.instrumentscientist_instrument.instrumentscientist_instrument(
                    name = '', 
                    description = '', )
            )
        else:
            return Instrumentscientist(
        )
        """

    def testInstrumentscientist(self):
        """Test Instrumentscientist"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
