# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.doi_data import DoiData

class TestDoiData(unittest.TestCase):
    """DoiData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DoiData:
        """Test DoiData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DoiData`
        """
        model = DoiData()
        if include_optional:
            return DoiData(
                title = '',
                abstract = '',
                dataset_id_list = [
                    1.337
                    ],
                data_collection_id = 1.337,
                keywords = [
                    ''
                    ],
                citation_publication_doi = '',
                reference_urls = [
                    ''
                    ],
                rights = ''
            )
        else:
            return DoiData(
                title = '',
                abstract = '',
        )
        """

    def testDoiData(self):
        """Test DoiData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
