# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.ewoks_session_id_jobs_put_request import EwoksSessionIdJobsPutRequest

class TestEwoksSessionIdJobsPutRequest(unittest.TestCase):
    """EwoksSessionIdJobsPutRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EwoksSessionIdJobsPutRequest:
        """Test EwoksSessionIdJobsPutRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EwoksSessionIdJobsPutRequest`
        """
        model = EwoksSessionIdJobsPutRequest()
        if include_optional:
            return EwoksSessionIdJobsPutRequest(
                status = '',
                step = icat_plus_client.models._ewoks__session_id__jobs_put_request_step._ewoks__sessionId__jobs_put_request_step(
                    name = '', 
                    status = '', 
                    message = '', ),
                log = None
            )
        else:
            return EwoksSessionIdJobsPutRequest(
        )
        """

    def testEwoksSessionIdJobsPutRequest(self):
        """Test EwoksSessionIdJobsPutRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
