# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.tracking_api import TrackingApi


class TestTrackingApi(unittest.TestCase):
    """TrackingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TrackingApi()

    def tearDown(self) -> None:
        pass

    def test_tracking_session_id_address_get(self) -> None:
        """Test case for tracking_session_id_address_get

        Returns all addresses associated to an user
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_delete(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_delete

        Deletes an existin address
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_get(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_get

        Returns a list of addresses associated to an investigation
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_post(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_post

        Creates a address
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_put(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_put

        Modifies an existin address
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_delete(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_delete

        Deletes an item
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_put(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_put

        Edits an item
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_post(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_post

        Creates an item associated to a parcel
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_labels_get(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_labels_get

        Returns a file with the labels
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_parcel_status_status_put(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_parcel_status_status_put

        Modifies a the status of a parcel
        """
        pass

    def test_tracking_session_id_parcel_get(self) -> None:
        """Test case for tracking_session_id_parcel_get

        Lists parcels
        """
        pass

    def test_tracking_session_id_parcel_post(self) -> None:
        """Test case for tracking_session_id_parcel_post

        It does create or update a new parcel
        """
        pass

    def test_tracking_session_id_parcel_put(self) -> None:
        """Test case for tracking_session_id_parcel_put

        It does create or update a new parcel
        """
        pass

    def test_tracking_session_id_setup_get(self) -> None:
        """Test case for tracking_session_id_setup_get

        Returns the the list of container types and parameters allowed to define experiment and processing plans
        """
        pass

    def test_tracking_session_id_shipment_delete(self) -> None:
        """Test case for tracking_session_id_shipment_delete

        Deletes a shipment
        """
        pass

    def test_tracking_session_id_shipment_get(self) -> None:
        """Test case for tracking_session_id_shipment_get

        Lists shipments associated to an investigation
        """
        pass

    def test_tracking_session_id_shipment_id_shipment_id_parcel_delete(self) -> None:
        """Test case for tracking_session_id_shipment_id_shipment_id_parcel_delete

        Deletes a parcel
        """
        pass

    def test_tracking_session_id_shipment_post(self) -> None:
        """Test case for tracking_session_id_shipment_post

        Creates a shipment associated to an investigation
        """
        pass

    def test_tracking_session_id_shipment_put(self) -> None:
        """Test case for tracking_session_id_shipment_put

        Modifies a shipment associated to an investigation
        """
        pass


if __name__ == '__main__':
    unittest.main()
