# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.users_api import USERSApi


class TestUSERSApi(unittest.TestCase):
    """USERSApi unit test stubs"""

    def setUp(self) -> None:
        self.api = USERSApi()

    def tearDown(self) -> None:
        pass

    def test_users_session_id_preferences_get(self) -> None:
        """Test case for users_session_id_preferences_get

        Returns the list of the user's preferences, user from the sessionId
        """
        pass

    def test_users_session_id_preferences_put(self) -> None:
        """Test case for users_session_id_preferences_put

        Update the user's preferences, user from the sessionId
        """
        pass


if __name__ == '__main__':
    unittest.main()
