# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.session_session_id_get200_response import SessionSessionIdGet200Response

class TestSessionSessionIdGet200Response(unittest.TestCase):
    """SessionSessionIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SessionSessionIdGet200Response:
        """Test SessionSessionIdGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SessionSessionIdGet200Response`
        """
        model = SessionSessionIdGet200Response()
        if include_optional:
            return SessionSessionIdGet200Response(
                remaining_minutes = 1.337,
                user_name = '',
                affiliation = '',
                email = '',
                full_name = '',
                user = {"sessionId":"b1a04f33-3989-4a12-81b8-6d589ff0c01a","username":"reader","name":"reader","fullName":"Anonymous","lifeTimeMinutes":720,"expirationTime":"2022-11-01T03:57:00.364Z","isAdministrator":false,"isInstrumentScientist":false,"isMinter":false,"usersByPrefix":[]}
            )
        else:
            return SessionSessionIdGet200Response(
        )
        """

    def testSessionSessionIdGet200Response(self):
        """Test SessionSessionIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
