# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.user_management_api import UserManagementApi


class TestUserManagementApi(unittest.TestCase):
    """UserManagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserManagementApi()

    def tearDown(self) -> None:
        pass

    def test_catalogue_session_id_instrumentscientist_delete(self) -> None:
        """Test case for catalogue_session_id_instrumentscientist_delete

        It deletes InstrumentScientists
        """
        pass

    def test_catalogue_session_id_instrumentscientist_get(self) -> None:
        """Test case for catalogue_session_id_instrumentscientist_get

        Get all InstrumentScientists
        """
        pass

    def test_catalogue_session_id_instrumentscientist_put(self) -> None:
        """Test case for catalogue_session_id_instrumentscientist_put

        It creates InstrumentScientists
        """
        pass

    def test_catalogue_session_id_user_name_name_instrumentscientist_get(self) -> None:
        """Test case for catalogue_session_id_user_name_name_instrumentscientist_get

        Get instrumentScientist by user name
        """
        pass


if __name__ == '__main__':
    unittest.main()
