# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.dataacquisition_api_key_base64_post_request import DataacquisitionApiKeyBase64PostRequest

class TestDataacquisitionApiKeyBase64PostRequest(unittest.TestCase):
    """DataacquisitionApiKeyBase64PostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataacquisitionApiKeyBase64PostRequest:
        """Test DataacquisitionApiKeyBase64PostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DataacquisitionApiKeyBase64PostRequest`
        """
        model = DataacquisitionApiKeyBase64PostRequest()
        if include_optional:
            return DataacquisitionApiKeyBase64PostRequest(
                var_base64 = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVQYV2NgYAAAAAMAAWgmWQ0AAAAASUVORK5CYII=',
                usernames = ''
            )
        else:
            return DataacquisitionApiKeyBase64PostRequest(
        )
        """

    def testDataacquisitionApiKeyBase64PostRequest(self):
        """Test DataacquisitionApiKeyBase64PostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
