# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.catalogue_api import CatalogueApi


class TestCatalogueApi(unittest.TestCase):
    """CatalogueApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CatalogueApi()

    def tearDown(self) -> None:
        pass

    def test_catalogue_instruments_get(self) -> None:
        """Test case for catalogue_instruments_get

        Returns all instruments
        """
        pass

    def test_catalogue_investigation_name_investigation_name_normalize_get(self) -> None:
        """Test case for catalogue_investigation_name_investigation_name_normalize_get

        Most of users don't write their proposal names using the same convention so it might happen that a given proposal can be written in many different ways. This method will homogenize such name.  Example IH-LS-0001, ihls0001, ih-LS-0001 are normalized like IH-LS-0001.
        """
        pass

    def test_catalogue_parameters_get(self) -> None:
        """Test case for catalogue_parameters_get

        Returns all parameters
        """
        pass

    def test_catalogue_session_id_datacollection_get(self) -> None:
        """Test case for catalogue_session_id_datacollection_get

        Gets all datacollection or for a given datasetId
        """
        pass

    def test_catalogue_session_id_datafile_download_get(self) -> None:
        """Test case for catalogue_session_id_datafile_download_get

        Downloads a file given its filepath.
        """
        pass

    def test_catalogue_session_id_datafile_get(self) -> None:
        """Test case for catalogue_session_id_datafile_get

        Get datafiles for a given dataset id.
        """
        pass

    def test_catalogue_session_id_dataset_get(self) -> None:
        """Test case for catalogue_session_id_dataset_get

        Gets datasets for a given investigationId or for a given datasetIds of for a sampleId or for a beamline
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_id_datacollection_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_id_datacollection_get

        Returns datacollections related to a given dataset along with a datasetId
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_id_datafile_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_id_datafile_get

        Get datafiles for a given dataset id. Method replaced by /catalogue/{sessionId}/datafile
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_ids_dataset_document_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_ids_dataset_document_get

        Get a list of dataset documents from a datasetId list. A dataset document is used for indexing a dataset in elastic search. It unflatters dataset's parameters.
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_ids_dataset_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_ids_dataset_get

        Get a list of dataset from a datasetId list
        """
        pass

    def test_catalogue_session_id_dataset_startdate_start_date_enddate_end_date_dataset_document_get(self) -> None:
        """Test case for catalogue_session_id_dataset_startdate_start_date_enddate_end_date_dataset_document_get

        Get a list of dataset documents by date range. A dataset document is used for indexing a dataset in elastic search. It unflatters dataset's parameters.
        """
        pass

    def test_catalogue_session_id_dataset_timeline_get(self) -> None:
        """Test case for catalogue_session_id_dataset_timeline_get

        Gets datasets timeline for a given investigationId or sampleId
        """
        pass

    def test_catalogue_session_id_datasetparameter_get(self) -> None:
        """Test case for catalogue_session_id_datasetparameter_get

        Returns the parameters
        """
        pass

    def test_catalogue_session_id_datasetparameter_put(self) -> None:
        """Test case for catalogue_session_id_datasetparameter_put

        Update a value of a dataset parameter
        """
        pass

    def test_catalogue_session_id_datasetparameter_values_get(self) -> None:
        """Test case for catalogue_session_id_datasetparameter_values_get

        Returns the values of the parameters
        """
        pass

    def test_catalogue_session_id_files_download_get(self) -> None:
        """Test case for catalogue_session_id_files_download_get

        Download the file associated to a sample
        """
        pass

    def test_catalogue_session_id_files_get(self) -> None:
        """Test case for catalogue_session_id_files_get

        Get the list of the files linked to a sample
        """
        pass

    def test_catalogue_session_id_files_upload_post(self) -> None:
        """Test case for catalogue_session_id_files_upload_post

        Upload a file and information linked to a sample
        """
        pass

    def test_catalogue_session_id_instruments_get(self) -> None:
        """Test case for catalogue_session_id_instruments_get

        Returns all instruments linked to the user
        """
        pass

    def test_catalogue_session_id_investigation_get(self) -> None:
        """Test case for catalogue_session_id_investigation_get

        Get investigations by sessionId
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_investigationusers_delete(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_investigationusers_delete

        Deletes a user from an investigation. Only allowed to PI, LocalContact and Beamline staff
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_investigationusers_get(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_investigationusers_get

        Gets users involved in a investigation
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_investigationusers_post(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_investigationusers_post

        Add users to an investigation. Only allowed to PI, LocalContact and Beamline staff
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_sample_get(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_sample_get

        Gets samples for a given investigationId
        """
        pass

    def test_catalogue_session_id_investigation_investigation_id_user_get(self) -> None:
        """Test case for catalogue_session_id_investigation_investigation_id_user_get

        Get user list of ICAT if the user if PI or LocalContact of the investigation, or InstrumentScientist or Administrator
        """
        pass

    def test_catalogue_session_id_investigation_timeline_get(self) -> None:
        """Test case for catalogue_session_id_investigation_timeline_get

        Gets investigation timeline for a given instrumentname
        """
        pass

    def test_catalogue_session_id_sample_parameters_id_put(self) -> None:
        """Test case for catalogue_session_id_sample_parameters_id_put

        Update sample parameter (description only if it is an editable sample or only sample comment)
        """
        pass

    def test_catalogue_session_id_samples_get(self) -> None:
        """Test case for catalogue_session_id_samples_get

        Gets samples
        """
        pass

    def test_catalogue_session_id_samples_sample_id_page_get(self) -> None:
        """Test case for catalogue_session_id_samples_sample_id_page_get

        Gets sample page for a given sample
        """
        pass

    def test_catalogue_session_id_samples_sample_id_sample_parameters_post(self) -> None:
        """Test case for catalogue_session_id_samples_sample_id_sample_parameters_post

        Create sample parameter (description only if it is an editable sample, or sample comment only)
        """
        pass

    def test_catalogue_session_id_user_get(self) -> None:
        """Test case for catalogue_session_id_user_get

        Get user list of ICAT (Restricted to administrators)
        """
        pass

    def test_catalogue_techniques_get(self) -> None:
        """Test case for catalogue_techniques_get

        Returns all techniques
        """
        pass


if __name__ == '__main__':
    unittest.main()
