# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.sample_metadata_api import SampleMetadataApi


class TestSampleMetadataApi(unittest.TestCase):
    """SampleMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SampleMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_samplemetadata_session_id_samples_delete(self) -> None:
        """Test case for samplemetadata_session_id_samples_delete

        Delete samples with metadata information for the given sampleIds
        """
        pass

    def test_samplemetadata_session_id_samples_files_delete(self) -> None:
        """Test case for samplemetadata_session_id_samples_files_delete

        Delete a metadata file
        """
        pass

    def test_samplemetadata_session_id_samples_files_get(self) -> None:
        """Test case for samplemetadata_session_id_samples_files_get

        Download a metadata file
        """
        pass

    def test_samplemetadata_session_id_samples_files_post(self) -> None:
        """Test case for samplemetadata_session_id_samples_files_post

        Upload one or more new files
        """
        pass

    def test_samplemetadata_session_id_samples_get(self) -> None:
        """Test case for samplemetadata_session_id_samples_get

        Returns the list of the samples with metadata information, user from the sessionId
        """
        pass

    def test_samplemetadata_session_id_samples_post(self) -> None:
        """Test case for samplemetadata_session_id_samples_post

        Creates a new sample
        """
        pass

    def test_samplemetadata_session_id_samples_put(self) -> None:
        """Test case for samplemetadata_session_id_samples_put

        Update an existing sample
        """
        pass


if __name__ == '__main__':
    unittest.main()
