# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.logbook_session_id_events_patch_request import LogbookSessionIdEventsPatchRequest

class TestLogbookSessionIdEventsPatchRequest(unittest.TestCase):
    """LogbookSessionIdEventsPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogbookSessionIdEventsPatchRequest:
        """Test LogbookSessionIdEventsPatchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogbookSessionIdEventsPatchRequest`
        """
        model = LogbookSessionIdEventsPatchRequest()
        if include_optional:
            return LogbookSessionIdEventsPatchRequest(
                event_ids = [
                    ''
                    ],
                tags = [
                    icat_plus_client.models.tag.tag(
                        _id = 56, 
                        name = '', 
                        color = '', 
                        description = '', 
                        beamline_name = '', 
                        investigation_id = '', )
                    ]
            )
        else:
            return LogbookSessionIdEventsPatchRequest(
        )
        """

    def testLogbookSessionIdEventsPatchRequest(self):
        """Test LogbookSessionIdEventsPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
