# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.actions_api import ActionsApi


class TestActionsApi(unittest.TestCase):
    """ActionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ActionsApi()

    def tearDown(self) -> None:
        pass

    def test_actions_session_id_logbook_instrumentname_put(self) -> None:
        """Test case for actions_session_id_logbook_instrumentname_put

        Actions related to the field instrumentName of the logbook
        """
        pass


if __name__ == '__main__':
    unittest.main()
