# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.h5_grove_api import H5GroveApi


class TestH5GroveApi(unittest.TestCase):
    """H5GroveApi unit test stubs"""

    def setUp(self) -> None:
        self.api = H5GroveApi()

    def tearDown(self) -> None:
        pass

    def test_h5grove_attr_get(self) -> None:
        """Test case for h5grove_attr_get

        It redirects to h5grove
        """
        pass

    def test_h5grove_data_get(self) -> None:
        """Test case for h5grove_data_get

        It redirects to h5grove
        """
        pass

    def test_h5grove_meta_get(self) -> None:
        """Test case for h5grove_meta_get

        It redirects to h5grove
        """
        pass

    def test_h5grove_stats_get(self) -> None:
        """Test case for h5grove_stats_get

        It redirects to h5grove
        """
        pass


if __name__ == '__main__':
    unittest.main()
